=============================
Welcome to Qinling Dashboard!
=============================

Qinling dashboard is a horizon plugin for Qinling.

* License: Apache license
* Documentation: https://docs.openstack.org/qinling-dashboard/latest/
* Source: https://git.openstack.org/cgit/openstack/qinling-dashboard
* Bugs: https://bugs.launchpad.net/qinling-dashboard

Team and repository tags
------------------------

.. image:: https://governance.openstack.org/tc/badges/qinling-dashboard.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html
